@@ -16,36 +16,39 @@
 */
 
 #include "menu.h"
+#include <KI18n/KLocalizedContext>
+#include <QQmlContext>
 #include <purpose/configuration.h>
 #include <purpose/alternativesmodel.h>
 #include <QPointer>
 #include <QDebug>
 #include <QQmlApplicationEngine>
-#include <KDeclarative/KDeclarative>
 
 using namespace Purpose;
 
-struct Purpose::MenuPrivate : public QObject
+class Purpose::MenuPrivate : public QObject
 {
 Q_OBJECT
 public:
     ~MenuPrivate() { m_engine->deleteLater(); }
     MenuPrivate(Menu* q)
         : QObject(q)
+        , m_engine(new QQmlApplicationEngine)
         , m_model(new AlternativesModel(q))
         , q(q)
-        , m_engine(new QQmlApplicationEngine)
     {
-        KDeclarative::KDeclarative decl;
-        decl.setDeclarativeEngine(m_engine);
-        decl.setupBindings();
+        m_engine->rootContext()->setContextObject(new KLocalizedContext(this));
         m_engine->load(QUrl(QStringLiteral("qrc:/JobDialog.qml")));
     }
 
     void trigger(int row) {
         Q_ASSERT(!m_engine->rootObjects().isEmpty());
-        QObject* o = m_engine->rootObjects().first();
+        QObject* o = m_engine->rootObjects().at(0);
 
+        if (!o) {
+            qWarning() << Q_FUNC_INFO << "object is NULL at m_engine" << m_engine << "rootObjects=" << m_engine->rootObjects();
+            return;
+        }
         o->setProperty("configuration", QVariant::fromValue<QObject*>(m_model->configureJob(row)));
         o->setProperty("q", QVariant::fromValue<QObject*>(q));
         o->setProperty("visible", true);
